pub struct ChannelLayout(/* private fields */);Implementations
Sourceimpl ChannelLayout
impl ChannelLayout
pub const FRONT_LEFT: ChannelLayout
pub const FRONT_RIGHT: ChannelLayout
pub const FRONT_CENTER: ChannelLayout
pub const LOW_FREQUENCY: ChannelLayout
pub const BACK_LEFT: ChannelLayout
pub const BACK_RIGHT: ChannelLayout
pub const FRONT_LEFT_OF_CENTER: ChannelLayout
pub const FRONT_RIGHT_OF_CENTER: ChannelLayout
pub const BACK_CENTER: ChannelLayout
pub const SIDE_LEFT: ChannelLayout
pub const SIDE_RIGHT: ChannelLayout
pub const TOP_CENTER: ChannelLayout
pub const TOP_FRONT_LEFT: ChannelLayout
pub const TOP_FRONT_CENTER: ChannelLayout
pub const TOP_FRONT_RIGHT: ChannelLayout
pub const TOP_BACK_LEFT: ChannelLayout
pub const TOP_BACK_CENTER: ChannelLayout
pub const TOP_BACK_RIGHT: ChannelLayout
pub const STEREO_LEFT: ChannelLayout
pub const STEREO_RIGHT: ChannelLayout
pub const WIDE_LEFT: ChannelLayout
pub const WIDE_RIGHT: ChannelLayout
pub const SURROUND_DIRECT_LEFT: ChannelLayout
pub const SURROUND_DIRECT_RIGHT: ChannelLayout
pub const LOW_FREQUENCY_2: ChannelLayout
pub const MONO: ChannelLayout
pub const STEREO: ChannelLayout
pub const _2POINT1: ChannelLayout
pub const _2_1: ChannelLayout
pub const SURROUND: ChannelLayout
pub const _3POINT1: ChannelLayout
pub const _4POINT0: ChannelLayout
pub const _4POINT1: ChannelLayout
pub const _2_2: ChannelLayout
pub const QUAD: ChannelLayout
pub const _5POINT0: ChannelLayout
pub const _5POINT1: ChannelLayout
pub const _5POINT0_BACK: ChannelLayout
pub const _5POINT1_BACK: ChannelLayout
pub const _6POINT0: ChannelLayout
pub const _6POINT0_FRONT: ChannelLayout
pub const HEXAGONAL: ChannelLayout
pub const _6POINT1: ChannelLayout
pub const _6POINT1_BACK: ChannelLayout
pub const _6POINT1_FRONT: ChannelLayout
pub const _7POINT0: ChannelLayout
pub const _7POINT0_FRONT: ChannelLayout
pub const _7POINT1: ChannelLayout
pub const _7POINT1_WIDE: ChannelLayout
pub const _7POINT1_WIDE_BACK: ChannelLayout
pub const OCTAGONAL: ChannelLayout
pub const HEXADECAGONAL: ChannelLayout
pub const STEREO_DOWNMIX: ChannelLayout
pub const _3POINT1POINT2: ChannelLayout
pub const _5POINT1POINT2_BACK: ChannelLayout
pub const _5POINT1POINT4_BACK: ChannelLayout
pub const _7POINT1POINT2: ChannelLayout
pub const _7POINT1POINT4_BACK: ChannelLayout
pub const CUBE: ChannelLayout
Sourceimpl ChannelLayout
impl ChannelLayout
Sourcepub const fn empty() -> ChannelLayout
pub const fn empty() -> ChannelLayout
Get a flags value with all bits unset.
Sourcepub const fn all() -> ChannelLayout
pub const fn all() -> ChannelLayout
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<ChannelLayout>
pub const fn from_bits(bits: u64) -> Option<ChannelLayout>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> ChannelLayout
pub const fn from_bits_truncate(bits: u64) -> ChannelLayout
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> ChannelLayout
pub const fn from_bits_retain(bits: u64) -> ChannelLayout
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ChannelLayout>
pub fn from_name(name: &str) -> Option<ChannelLayout>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ChannelLayout) -> bool
pub const fn intersects(&self, other: ChannelLayout) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ChannelLayout) -> bool
pub const fn contains(&self, other: ChannelLayout) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: ChannelLayout)
pub fn insert(&mut self, other: ChannelLayout)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: ChannelLayout)
pub fn remove(&mut self, other: ChannelLayout)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ChannelLayout)
pub fn toggle(&mut self, other: ChannelLayout)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ChannelLayout, value: bool)
pub fn set(&mut self, other: ChannelLayout, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ChannelLayout) -> ChannelLayout
pub const fn intersection(self, other: ChannelLayout) -> ChannelLayout
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ChannelLayout) -> ChannelLayout
pub const fn union(self, other: ChannelLayout) -> ChannelLayout
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: ChannelLayout) -> ChannelLayout
pub const fn difference(self, other: ChannelLayout) -> ChannelLayout
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ChannelLayout) -> ChannelLayout
pub const fn symmetric_difference(self, other: ChannelLayout) -> ChannelLayout
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ChannelLayout
pub const fn complement(self) -> ChannelLayout
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ChannelLayout
impl ChannelLayout
Sourcepub const fn iter(&self) -> Iter<ChannelLayout>
pub const fn iter(&self) -> Iter<ChannelLayout>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ChannelLayout>
pub const fn iter_names(&self) -> IterNames<ChannelLayout>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ChannelLayout
impl ChannelLayout