pub struct AutoAudioBuffer { /* private fields */ }Expand description
auto re-sample and buffer the audio frame from the decoder to the encoder
some encode, like opus support variable frame size, the frame decoded from other format may not be the same as the frame size of the encoder, this filter graph will handle the re-sample and frame split.
Implementations
Sourceimpl AutoAudioBuffer
impl AutoAudioBuffer
pub fn new<S, D>(src: S, dst: D) -> FFmpegResult<Self>
pub fn add_frame(&mut self, frame: &AudioFrame) -> FFmpegResult
pub fn recv_frames<F>(&mut self, cb: &mut F) -> FFmpegResult
pub fn flush(&mut self) -> FFmpegResult